@@ -29,14 +29,14 @@ _gnutls_record_buffer_put (gnutls_session_t session,
   content_type_t type, uint64* seq, mbuffer_st* bufel);
 
 inline static int
-_gnutls_record_buffer_get_size (content_type_t type, gnutls_session_t session)
+_gnutls_record_buffer_get_size (gnutls_session_t session)
 {
   return session->internals.record_buffer.byte_length;
 }
 
 int _gnutls_record_buffer_get (content_type_t type,
-                               gnutls_session_t session, opaque * data,
-                               size_t length, opaque seq[8]);
+                               gnutls_session_t session, uint8_t * data,
+                               size_t length, uint8_t seq[8]);
 ssize_t _gnutls_io_read_buffered (gnutls_session_t, size_t n, content_type_t);
 int _gnutls_io_clear_peeked_data (gnutls_session_t session);
 
@@ -50,7 +50,7 @@ int _gnutls_handshake_io_cache_int (gnutls_session_t,
 ssize_t
 _gnutls_handshake_io_recv_int (gnutls_session_t session,
                                gnutls_handshake_description_t htype,
-                               handshake_buffer_st * hsk);
+                               handshake_buffer_st * hsk, unsigned int optional);
 
 ssize_t _gnutls_io_write_flush (gnutls_session_t session);
 int
@@ -88,6 +88,9 @@ int i;
   session->internals.handshake_recv_buffer_size = 0;
 }
 
+int
+_gnutls_parse_record_buffered_msgs (gnutls_session_t session);
+
 ssize_t
 _gnutls_recv_in_buffers (gnutls_session_t session, content_type_t type,
                   gnutls_handshake_description_t htype);
