@@ -492,7 +492,7 @@ gnutls_ocsp_req_get_cert_id (gnutls_ocsp_req_t req,
       return ret;
     }
 
-  ret = _gnutls_x509_oid2digest_algorithm ((char*)sa.data);
+  ret = _gnutls_x509_oid_to_digest ((char*)sa.data);
   _gnutls_free_datum (&sa);
   if (ret < 0)
     {
@@ -1354,7 +1354,7 @@ gnutls_ocsp_resp_get_single (gnutls_ocsp_resp_t resp,
       return ret;
     }
 
-  ret = _gnutls_x509_oid2digest_algorithm ((char*)sa.data);
+  ret = _gnutls_x509_oid_to_digest ((char*)sa.data);
   _gnutls_free_datum (&sa);
   if (ret < 0)
     {
@@ -1771,7 +1771,7 @@ gnutls_ocsp_resp_get_certs (gnutls_ocsp_resp_t resp,
     {
       char name[ASN1_MAX_NAME_SIZE];
 
-      snprintf (name, sizeof (name), "certs.?%lu", ctr + 1);
+      snprintf (name, sizeof (name), "certs.?%u", (unsigned int)(ctr + 1));
       ret = _gnutls_x509_der_encode (resp->basicresp, name, &c, 0);
       if (ret == GNUTLS_E_ASN1_ELEMENT_NOT_FOUND)
 	break;
