@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010, 2012 Free Software Foundation, Inc.
+ * Copyright (C) 2004-2012 Free Software Foundation, Inc.
  *
  * Author: Simon Josefsson
  *
@@ -183,7 +183,7 @@ static gnutls_dh_params_t dh_params;
 static int
 generate_dh_params (void)
 {
-  const gnutls_datum_t p3 = { (char *) pkcs3, strlen (pkcs3) };
+  const gnutls_datum_t p3 = { (void *) pkcs3, strlen (pkcs3) };
   /* Generate Diffie-Hellman parameters - for use with DHE
    * kx algorithms. These should be discarded and regenerated
    * once a day, once a week or once a month. Depending on the
@@ -197,7 +197,7 @@ int err, listen_sd, i;
 int sd, ret;
 struct sockaddr_in sa_serv;
 struct sockaddr_in sa_cli;
-int client_len;
+socklen_t client_len;
 char topbuf[512];
 gnutls_session_t session;
 char buffer[MAX_BUF + 1];
